summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--locale/pt_BR/LC_MESSAGES/statusnet.mobin74412 -> 74412 bytes
-rw-r--r--plugins/InfiniteScroll/infinitescroll.js2
-rw-r--r--plugins/Meteor/meteorupdater.js2
-rw-r--r--plugins/Realtime/RealtimePlugin.php13
-rw-r--r--scripts/updateavatarurl.php128
5 files changed, 135 insertions, 10 deletions
diff --git a/locale/pt_BR/LC_MESSAGES/statusnet.mo b/locale/pt_BR/LC_MESSAGES/statusnet.mo
index fcec3270e..cdad8cc6c 100644
--- a/locale/pt_BR/LC_MESSAGES/statusnet.mo
+++ b/locale/pt_BR/LC_MESSAGES/statusnet.mo
Binary files differ
diff --git a/plugins/InfiniteScroll/infinitescroll.js b/plugins/InfiniteScroll/infinitescroll.js
index 0dafef6d5..0c8edce2b 100644
--- a/plugins/InfiniteScroll/infinitescroll.js
+++ b/plugins/InfiniteScroll/infinitescroll.js
@@ -1,6 +1,6 @@
jQuery(document).ready(function($){
$('notices_primary').infinitescroll({
- debug: true,
+ debug: false,
infiniteScroll : false,
nextSelector : 'body#public li.nav_next a,'+
'body#all li.nav_next a,'+
diff --git a/plugins/Meteor/meteorupdater.js b/plugins/Meteor/meteorupdater.js
index 9ce68775b..cdd1d63fa 100644
--- a/plugins/Meteor/meteorupdater.js
+++ b/plugins/Meteor/meteorupdater.js
@@ -1,6 +1,4 @@
// Update the local timeline from a Meteor server
-// XXX: If @a is subscribed to @b, @a should get @b's notices in @a's Personal timeline.
-// Do Replies timeline.
var MeteorUpdater = function()
{
diff --git a/scripts/updateavatarurl.php b/scripts/updateavatarurl.php
new file mode 100644
index 000000000..dfcfc118c
--- /dev/null
+++ b/scripts/updateavatarurl.php
@@ -0,0 +1,128 @@
+#!/usr/bin/env php
+<?php
+/*
+ * StatusNet - a distributed open-source microblogging tool
+ * Copyright (C) 2008, 2009, StatusNet, Inc.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
+
+define('INSTALLDIR', realpath(dirname(__FILE__) . '/..'));
+
+$shortoptions = 'i:n:a';
+$longoptions = array('id=', 'nickname=', 'all');
+
+$helptext = <<<END_OF_UPDATEAVATARURL_HELP
+updateavatarurl.php [options]
+update the URLs of all avatars in the system
+
+ -i --id ID of user to update
+ -n --nickname nickname of the user to update
+ -a --all update all
+
+END_OF_UPDATEAVATARURL_HELP;
+
+require_once INSTALLDIR.'/scripts/commandline.inc';
+
+try {
+ $user = null;
+
+ if (have_option('i', 'id')) {
+ $id = get_option_value('i', 'id');
+ $user = User::staticGet('id', $id);
+ if (empty($user)) {
+ throw new Exception("Can't find user with id '$id'.");
+ }
+ updateAvatars($user);
+ } else if (have_option('n', 'nickname')) {
+ $nickname = get_option_value('n', 'nickname');
+ $user = User::staticGet('nickname', $nickname);
+ if (empty($user)) {
+ throw new Exception("Can't find user with nickname '$nickname'");
+ }
+ updateAvatars($user);
+ } else if (have_option('a', 'all')) {
+ $user = new User();
+ if ($user->find()) {
+ while ($user->fetch()) {
+ updateAvatars($user);
+ }
+ }
+ } else {
+ throw new Exception("You have to provide an ID or nickname or 'all'.");
+ }
+} catch (Exception $e) {
+ print $e->getMessage()."\n";
+ exit(1);
+}
+
+function updateAvatars($user)
+{
+ $touched = false;
+
+ if (!have_option('q', 'quiet')) {
+ print "Updating avatars for user '".$user->nickname."' (".$user->id.")...";
+ }
+
+ $avatar = new Avatar();
+
+ $avatar->profile_id = $user->id;
+
+ if (!$avatar->find()) {
+ if (have_option('v', 'verbose')) {
+ print "(none found)...";
+ }
+ } else {
+ while ($avatar->fetch()) {
+ if (have_option('v', 'verbose')) {
+ if ($avatar->original) {
+ print "original...";
+ } else {
+ print $avatar->width."...";
+ }
+ }
+
+ $orig = clone($avatar);
+
+ $avatar->url = Avatar::url($avatar->filename);
+
+ if ($avatar->url != $orig->url) {
+ $sql =
+ "UPDATE avatar SET url = '" . $avatar->url . "' ".
+ "WHERE profile_id = " . $avatar->profile_id . " ".
+ "AND width = " . $avatar->width . " " .
+ "AND height = " . $avatar->height . " ";
+
+ if ($avatar->original) {
+ $sql .= "AND original = 1 ";
+ }
+
+ if (!$avatar->query($sql)) {
+ throw new Exception("Can't update avatar for user " . $user->nickname . ".");
+ } else {
+ $touched = true;
+ }
+ }
+ }
+ }
+
+ if ($touched) {
+ $profile = $user->getProfile();
+ common_broadcast_profile($profile);
+ }
+
+ if (have_option('v', 'verbose')) {
+ print "DONE.\n";
+ }
+}
diff --git a/plugins/Realtime/RealtimePlugin.php b/plugins/Realtime/RealtimePlugin.php
index c5fb6de03..198cb5ad7 100644
--- a/plugins/Realtime/RealtimePlugin.php
+++ b/plugins/Realtime/RealtimePlugin.php
@@ -139,8 +139,8 @@ class RealtimePlugin extends Plugin
// Add to the public timeline
- if ($notice->is_local ||
- ($notice->is_local == 0 && !common_config('public', 'localonly'))) {
+ if ($notice->is_local == Notice::LOCAL_PUBLIC ||
+ ($notice->is_local == Notice::REMOTE_OMB && !common_config('public', 'localonly'))) {
$paths[] = array('public');
}
@@ -237,7 +237,6 @@ class RealtimePlugin extends Plugin
}
$action->showContentBlock();
- $action->showScripts();
$action->elementEnd('body');
return false; // No default processing
}
@@ -247,13 +246,13 @@ class RealtimePlugin extends Plugin
// FIXME: this code should be abstracted to a neutral third
// party, like Notice::asJson(). I'm not sure of the ethics
// of refactoring from within a plugin, so I'm just abusing
- // the ApiAction method. Don't do this unless you're me!
+ // the TwitterApiAction method. Don't do this unless you're me!
- require_once(INSTALLDIR.'/lib/api.php');
+ require_once(INSTALLDIR.'/lib/twitterapi.php');
- $act = new ApiAction('/dev/null');
+ $act = new TwitterApiAction('/dev/null');
- $arr = $act->twitterStatusArray($notice, true);
+ $arr = $act->twitter_status_array($notice, true);
$arr['url'] = $notice->bestUrl();
$arr['html'] = htmlspecialchars($notice->rendered);
$arr['source'] = htmlspecialchars($arr['source']);